@@ -2,6 +2,7 @@ import braintree
 from braintree.resource import Resource
 from braintree.configuration import Configuration
 from braintree.ach_mandate import AchMandate
+from braintree.us_bank_account_verification import UsBankAccountVerification
 
 class UsBankAccount(Resource):
 
@@ -33,7 +34,12 @@ class UsBankAccount(Resource):
 
     def __init__(self, gateway, attributes):
         Resource.__init__(self, gateway, attributes)
-        if "ach_mandate" in attributes:
+        if attributes.get("ach_mandate") is not None:
             self.ach_mandate = AchMandate(gateway, self.ach_mandate)
         else:
             self.ach_mandate = None
+
+        if attributes.get("verifications") is not None:
+            self.verifications = [UsBankAccountVerification(gateway, v) for v in self.verifications]
+        else:
+            self.verifications = None
